@@ -4,10 +4,7 @@
 enumerate.loops <- function(CM) {
 
 # is.loop tests that a list of visited elements begins at and 
-# terminates in the jth parameter. It returns TRUE or FALSE and takes:
-# LOVE: a list of visited elements
-# j: a parameter that terminates a path from i to j, where i = j
-
+# terminates in the ith parameter. It returns TRUE or FALSE
 	is.loop <- function() {
 		if ( (LOVE[length(LOVE)] == LOVE[1]) & (length(LOVE) > 1) ) {
 			return(TRUE)
@@ -21,14 +18,11 @@ enumerate.loops <- function(CM) {
 
 # make.ENVY() returns a list of Elements Not Visted Yet (ENVY), excluding
 # the first element from:
-# CM: a valid Community Matrix
-# Term: a valid Termination matrix
-# LOVE: a list of visited elements within CM 
 	make.ENVY <- function() {
 		ENVY <- NULL
 		for (z in 1:N) {
-			if (!(identical((CM[LOVE[length(LOVE)],z]),0))) {
-				if (identical(Term[LOVE[length(LOVE)],z],0)) {
+			if (!(identical((CM[z,LOVE[length(LOVE)]]),0))) {
+				if (identical(Term[z,LOVE[length(LOVE)]],0)) {
 					ENVY <- c(ENVY,z)
 					}
 				}
@@ -44,28 +38,22 @@ enumerate.loops <- function(CM) {
 		}
 
 	# update.Term() clears rows in the termination matrix Term of any
-	# parameters not in the List Of Visited Elements (LOVE). It
-	# returns Term and takes:
-	# Term: a valid Termination matrix
-	# LOVE: a list of visited elements from the community matrix to 
-	#       which Term is relevant
+	# parameters not in the List Of Visited Elements (LOVE).
 	update.Term <- function() {
 		for (y in 1:N) {
 			if (!(y %in% LOVE) ) {
-				Term[y,c(1:N)] <<- 0
+				Term[c(1:N),y] <<- 0
 				}
 			}
 
-		Term[1:x-1,1:N] <<- 1
 		Term[1:N,1:x-1] <<- 1
+		Term[1:x-1,1:N] <<- 1
 			
 		# end update.Term()
 		}
 
 	# add.LOVE.to.LOL adds the List Of Visited Elements (LOVE) to the
-	# List Of Loops (LOL) and returns LOL. It takes:
-	# LOVE: a list of visited elements
-	# LOL: a list of paths
+	# List Of Loops (LOL)
 	add.LOVE.to.LOL <- function() {
 		if (is.null(LOL)) {
 			LOL <<- list(LOVE)
@@ -76,17 +64,12 @@ enumerate.loops <- function(CM) {
 		 # end add.LOVE.to.LOL()
 		 }
 
-	# search.step is the main logic of the breadth-wide path search. It
-	# returns a list of paths (LOL), and takes:
-	# CM: a valid Community Matrix
-	# Term: a valid Termination matrix
-	# LOVE: a list of visited elements within CM
-	# LOL: a list of paths within CM 
+	# search.step is the main logic of the breadth-wide path search.
 	search.step <- function() {
 		
 		ENVY <- make.ENVY()
 		if (length(ENVY) == 0) {
-			Term[LOVE[length(LOVE)-1],LOVE[length(LOVE)]] <<- 1
+			Term[LOVE[length(LOVE)],LOVE[length(LOVE)-1]] <<- 1
 			LOVE <<- LOVE[-length(LOVE)]
 		   update.Term()
 
@@ -104,7 +87,7 @@ enumerate.loops <- function(CM) {
 			# test whether new LOVE is a loop and respond accordingly
 			if (is.loop() == TRUE) {
 				add.LOVE.to.LOL()
-				Term[LOVE[length(LOVE)-1],LOVE[length(LOVE)]] <<- 1
+				Term[LOVE[length(LOVE)],LOVE[length(LOVE)-1]] <<- 1
 				LOVE <<- LOVE[-length(LOVE)]
 				}
  			}
